pub struct EndpointMetadata {
pub product: String,
pub component: String,
pub lambda_context: Context,
pub stage: Option<String>,
pub allowed_methods: String,
pub response_content_type: String,
}Expand description
Metadata for a specific endpoint.
Fields
product: StringProduct name (Application name).
component: StringComponent or section name.
lambda_context: ContextThe AWS Lambda function execution context.
NOTE: The values in this struct are populated using the Lambda environment variables and the headers returned by the poll request to the Runtime APIs.
stage: Option<String>Current stage it’s running within.
allowed_methods: StringAllowed HTTP methods for the endpoint.
response_content_type: StringResponse content type for the endpoint.
Implementations
Sourceimpl EndpointMetadata
impl EndpointMetadata
pub fn builder() -> EndpointMetadataBuilder
Sourcepub fn lambda_url(&self) -> Result<String, Error>
pub fn lambda_url(&self) -> Result<String, Error>
Get the URL to the lambda function currently running.